@@ -55,15 +55,12 @@ require_once 'TestCase.php';
  * @license   http://www.gnu.org/copyleft/lesser.html LGPL License 2.1
  * @link      http://pear.php.net/package/Crypt_GPG
  */
-class GeneralTestCase extends Crypt_GPG_TestCase
+class GeneralTest extends Crypt_GPG_TestCase
 {
-    // {{{ testPublicKeyringFileException()
-
-    /**
-     * @expectedException Crypt_GPG_FileException
-     */
     public function testPublicKeyringFileException()
     {
+        $this->expectException('Crypt_GPG_FileException');
+
         $publicKeyringFile = $this->getTempFilename('pubring.gpg');
         new Crypt_GPG(
             array(
@@ -72,14 +69,10 @@ class GeneralTestCase extends Crypt_GPG_TestCase
         );
     }
 
-    // }}}
-    // {{{ testPrivateKeyringFileException()
-
-    /**
-     * @expectedException Crypt_GPG_FileException
-     */
     public function testPrivateKeyringFileException()
     {
+        $this->expectException('Crypt_GPG_FileException');
+
         $privateKeyringFile = $this->getTempFilename('secring.gpg');
         new Crypt_GPG(
             array(
@@ -88,14 +81,10 @@ class GeneralTestCase extends Crypt_GPG_TestCase
         );
     }
 
-    // }}}
-    // {{{ testTrustDatabaseFileException()
-
-    /**
-     * @expectedException Crypt_GPG_FileException
-     */
     public function testTrustDatabaseFileException()
     {
+        $this->expectException('Crypt_GPG_FileException');
+
         $trustDbFile = $this->getTempFilename('secring.gpg');
         new Crypt_GPG(
             array(
@@ -104,15 +93,11 @@ class GeneralTestCase extends Crypt_GPG_TestCase
         );
     }
 
-    // }}}
-    // {{{ testHomedirFileException_NoCreate()
-
-    /**
-     * @expectedException Crypt_GPG_FileException
-     * @expectedExceptionMessage cannot be created
-     */
     public function testHomedirFileException_NoCreate()
     {
+        $this->expectException('Crypt_GPG_FileException');
+        $this->expectExceptionMessage('cannot be created');
+
         if (posix_getuid() === 0) {
             $this->markTestSkipped('Root can write to any homedir.');
         }
@@ -121,15 +106,11 @@ class GeneralTestCase extends Crypt_GPG_TestCase
         new Crypt_GPG(array('homedir' => $nonCreatableDirectory));
     }
 
-    // }}}
-    // {{{ testHomedirFileException_NoExecute()
-
-    /**
-     * @expectedException Crypt_GPG_FileException
-     * @expectedExceptionMessage is not enterable
-     */
     public function testHomedirFileException_NoExecute()
     {
+        $this->expectException('Crypt_GPG_FileException');
+        $this->expectExceptionMessage('is not enterable');
+
         if (posix_getuid() === 0) {
             $this->markTestSkipped('Root can do what it wants to any homedir.');
         }
@@ -141,15 +122,11 @@ class GeneralTestCase extends Crypt_GPG_TestCase
         new Crypt_GPG(array('homedir' => $nonExecutableDirectory));
     }
 
-    // }}}
-    // {{{ testHomedirFileException_NoWrite()
-
-    /**
-     * @expectedException Crypt_GPG_FileException
-     * @expectedExceptionMessage is not writable
-     */
     public function testHomedirFileException_NoWrite()
     {
+        $this->expectException('Crypt_GPG_FileException');
+        $this->expectExceptionMessage('is not writable');
+
         if (posix_getuid() === 0) {
             $this->markTestSkipped('Root can write to any homedir.');
         }
@@ -161,57 +138,29 @@ class GeneralTestCase extends Crypt_GPG_TestCase
         new Crypt_GPG(array('homedir' => $nonWriteableDirectory));
     }
 
-    // }}}
-    // {{{ testBinaryPEARException()
-
-    /**
-     * @expectedException PEAR_Exception
-     */
     public function testBinaryPEARException()
     {
+        $this->expectException('PEAR_Exception');
+
         new Crypt_GPG(array('binary' => './non-existent-binary'));
     }
 
-    // }}}
-    // {{{ testGPGBinaryPEARException()
-
-    /**
-     * @expectedException PEAR_Exception
-     */
     public function testGPGBinaryPEARException()
     {
+        $this->expectException('PEAR_Exception');
+
         new Crypt_GPG(array('gpgBinary' => './non-existent-binary'));
     }
 
-    // }}}
-    // {{{ testSetEngine()
-
     public function testSetEngine()
     {
         $engine = new Crypt_GPG_Engine($this->getOptions());
         $gpg = new Crypt_GPG();
         $gpg->setEngine($engine);
 
-        $homedirConstraint = $this->attribute(
-            $this->attributeEqualTo(
-                '_homedir',
-                __DIR__ . '/' . self::HOMEDIR
-            ),
-            'engine'
-        );
-
-        $this->assertThat(
-            $gpg,
-            $homedirConstraint,
-            'Engine was not set properly.'
-        );
+        $this->assertSame($this->getPropertyValue('Crypt_GPG', $gpg, 'engine'), $engine);
     }
 
-    // }}}
-
-    // fluent interface
-    // {{{ testFluentInterface
-
     /**
      * @group fluent
      */
@@ -282,8 +231,4 @@ class GeneralTestCase extends Crypt_GPG_TestCase
             'method.'
         );
     }
-
-    // }}}
 }
-
-?>
